@@ -22,6 +22,8 @@ This file implements test cases for emoji candidates
 '''
 
 import sys
+import os
+import importlib.util
 import logging
 import unittest
 
@@ -41,21 +43,7 @@ import testutils # pylint: disable=import-error
 # added, changed, or missing.
 itb_emoji.DOMAINNAME = ''
 
-IMPORT_ENCHANT_SUCCESSFUL = False
-IMPORT_HUNSPELL_SUCCESSFUL = False
-try:
-    # pylint: disable=unused-import
-    import enchant # type: ignore
-    # pylint: enable=unused-import
-    IMPORT_ENCHANT_SUCCESSFUL = True
-except (ImportError,):
-    try:
-        # pylint: disable=unused-import
-        import hunspell # type: ignore
-        # pylint: enable=unused-import
-        IMPORT_HUNSPELL_SUCCESSFUL = True
-    except (ImportError,):
-        pass
+IS_ENCHANT_AVAILABLE = importlib.util.find_spec('enchant') is not None
 
 # pylint: disable=missing-function-docstring
 # pylint: disable=missing-class-docstring
@@ -63,7 +51,8 @@ except (ImportError,):
 # pylint: disable=line-too-long
 
 @unittest.skipIf(
-    '..' not in itb_emoji.find_cldr_annotation_path('en'),
+    os.path.abspath(os.path.join(os.path.dirname(__file__), '../data/annotations'))
+    != os.path.abspath(os.path.dirname(itb_emoji.find_cldr_annotation_path('en'))),
     f'Using external emoji annotations: '
     f'{itb_emoji.find_cldr_annotation_path("en")} '
     f'Testing with older emoji annotations instead '
@@ -414,7 +403,7 @@ class EmojiCandidatesTestCase(unittest.TestCase):
         self.assertEqual(first_match.comment, 'flag: svalbard & jan mayen')
 
     @unittest.skipUnless(
-        IMPORT_ENCHANT_SUCCESSFUL,
+        IS_ENCHANT_AVAILABLE,
         "Skipping because this test requires python3-enchant to work.")
     @unittest.skipUnless(
         testutils.enchant_working_as_expected(),
@@ -448,7 +437,7 @@ class EmojiCandidatesTestCase(unittest.TestCase):
         self.assertEqual(first_match.comment, 'people holding hands')
 
     @unittest.skipUnless(
-        IMPORT_ENCHANT_SUCCESSFUL,
+        IS_ENCHANT_AVAILABLE,
         "Skipping because this test requires python3-enchant to work.")
     @unittest.skipUnless(
         testutils.enchant_working_as_expected(),
@@ -510,7 +499,7 @@ class EmojiCandidatesTestCase(unittest.TestCase):
         self.assertEqual(first_match.comment, 'baby bottle [birth]')
 
     @unittest.skipUnless(
-        IMPORT_ENCHANT_SUCCESSFUL,
+        IS_ENCHANT_AVAILABLE,
         "Skipping because this test requires python3-enchant to work.")
     @unittest.skipUnless(
         testutils.enchant_working_as_expected(),
@@ -538,7 +527,7 @@ class EmojiCandidatesTestCase(unittest.TestCase):
         self.assertTrue(first_match.comment.startswith('peace symbol'))
 
     @unittest.skipUnless(
-        IMPORT_ENCHANT_SUCCESSFUL,
+        IS_ENCHANT_AVAILABLE,
         "Skipping because this test requires python3-enchant to work.")
     @unittest.skipUnless(
         testutils.enchant_working_as_expected(),
@@ -669,7 +658,7 @@ class EmojiCandidatesTestCase(unittest.TestCase):
         self.assertEqual(first_match.comment, 'anchor')
 
     @unittest.skipUnless(
-        IMPORT_ENCHANT_SUCCESSFUL,
+        IS_ENCHANT_AVAILABLE,
         "Skipping because this test requires python3-enchant to work.")
     @unittest.skipUnless(
         testutils.enchant_working_as_expected(),
